@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-09 15:00:05
-@LastEditTime: 2021-09-03 09:00:29
+@LastEditTime: 2021-09-09 20:06:10
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -58,14 +58,20 @@ class SyncPayOrderHandler(TaoBaseHandler):
         user_id = int(self.get_param("tb_user_id", 0))
         module_id = int(self.get_param("module_id", 0))
         login_token = self.get_param("login_token")
-        is_log = self.get_param("is_log",False)
-        order_base_model = OrderBaseModel(context=self)
+        is_log = bool(self.get_param("is_log", False))
 
         invoke_result_data = self.business_process_executing(app_id, act_id, user_id, module_id, login_token)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         app_key, app_secret = self.get_app_key_secret()
-        invoke_result_data = order_base_model.sync_tao_pay_order(app_id, act_id, module_id, user_id, login_token, self.__class__.__name__, self.request_code, invoke_result_data.data["asset_type"], invoke_result_data.data["goods_id"], invoke_result_data.data["sku_id"], invoke_result_data.data["ascription_type"], app_key, app_secret, is_log, invoke_result_data.data["check_user_nick"], invoke_result_data.data["continue_request_expire"])
+        order_base_model = OrderBaseModel(context=self)
+        asset_type = invoke_result_data.data["asset_type"] if invoke_result_data.data.__contains__("asset_type") else 3
+        goods_id = invoke_result_data.data["goods_id"] if invoke_result_data.data.__contains__("goods_id") else ""
+        sku_id = invoke_result_data.data["sku_id"] if invoke_result_data.data.__contains__("sku_id") else ""
+        ascription_type = invoke_result_data.data["ascription_type"] if invoke_result_data.data.__contains__("ascription_type") else 1
+        check_user_nick = invoke_result_data.data["check_user_nick"] if invoke_result_data.data.__contains__("check_user_nick") else True
+        continue_request_expire = invoke_result_data.data["continue_request_expire"] if invoke_result_data.data.__contains__("continue_request_expire") else 5
+        invoke_result_data = order_base_model.sync_tao_pay_order(app_id, act_id, module_id, user_id, login_token, self.__class__.__name__, self.request_code, asset_type, goods_id, sku_id, ascription_type, app_key, app_secret, is_log, check_user_nick, continue_request_expire)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         invoke_result_data = self.business_process_executed(app_id, act_id, module_id, user_id, open_id, invoke_result_data)
@@ -100,13 +106,12 @@ class SyncPayOrderHandler(TaoBaseHandler):
         :return:
         :last_editors: HuangJianYi
         """
-        if invoke_result_data.success == True:
-            stat_base_model = StatBaseModel(context=self)
-            key_list_dict = {}
-            key_list_dict["PayUserCount"] = 1
-            key_list_dict["PayCount"] = invoke_result_data.data["pay_num"]
-            key_list_dict["PayMoneyCount"] = invoke_result_data.data["pay_price"]
-            stat_base_model.add_stat_list(app_id, act_id, module_id, user_id, open_id, key_list_dict)
+        stat_base_model = StatBaseModel(context=self)
+        key_list_dict = {}
+        key_list_dict["PayUserCount"] = 1
+        key_list_dict["PayCount"] = invoke_result_data.data["pay_num"]
+        key_list_dict["PayMoneyCount"] = invoke_result_data.data["pay_price"]
+        stat_base_model.add_stat_list(app_id, act_id, module_id, user_id, open_id, key_list_dict)
         return invoke_result_data
 
 
