@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-26 18:31:06
-@LastEditTime: 2021-09-09 13:33:27
+@LastEditTime: 2021-09-09 18:40:24
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -49,7 +49,7 @@ class LoginHandler(TaoBaseHandler):
         invoke_result_data = user_base_model.save_user_by_openid(app_id, act_id, open_id, user_nick, avatar)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        invoke_result_data = self.business_process_executed(invoke_result_data)
+        invoke_result_data = self.business_process_executed(invoke_result_data, app_id, act_id, module_id, open_id, user_nick, avatar)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         return self.response_json_success(invoke_result_data.data)
@@ -122,7 +122,7 @@ class CheckIsMemberHandler(TaoBaseHandler):
         :last_editors: HuangJianYi
         """
         app_id = self.get_taobao_param().source_app_id
-        is_log = self.get_param("is_log", False)
+        is_log = bool(self.get_param("is_log", False))
         app_base_model = AppBaseModel(context=self)
         app_info_dict = app_base_model.get_app_info_dict(app_id)
         if not app_info_dict:
@@ -179,7 +179,7 @@ class GetCouponPrizeHandler(TaoBaseHandler):
         app_id = self.get_taobao_param().source_app_id
         open_id = self.get_taobao_param().open_id
         user_prize_id = int(self.get_param("user_prize_id", 0))
-        is_log = self.get_param("is_log", False)
+        is_log = bool(self.get_param("is_log", False))
         app_base_model = AppBaseModel(context=self)
         app_info_dict = app_base_model.get_app_info_dict(app_id)
         if not app_info_dict:
