@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-09 14:11:52
-@LastEditTime: 2021-09-09 14:37:49
+@LastEditTime: 2021-09-09 19:58:37
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -146,9 +146,9 @@ class PrizeRosterListHandler(TaoBaseHandler):
         order_by ="create_date desc"
         invoke_result_data = self.business_process_executing(self.request_params)
         if invoke_result_data.success == True:
-            condition = invoke_result_data.data["condition"]
-            params = invoke_result_data.data["params"]
-            order_by = invoke_result_data.data["order_by"]
+            condition = invoke_result_data.data["condition"] if invoke_result_data.data.__contains__("condition") else ""
+            params = invoke_result_data.data["params"] if invoke_result_data.data.__contains__("params") else []
+            order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "create_date desc"
         order_base_model = OrderBaseModel(context=self)
         return self.response_json_success(order_base_model.get_prize_roster_list(app_id, act_id, module_id, user_id, user_open_id, user_nick, order_no, goods_type, prize_type, logistics_status, prize_status, pay_status, page_size, page_index, create_date_start, create_date_end,order_by=order_by, condition=condition,params=params))
 
@@ -163,6 +163,7 @@ class PrizeRosterListHandler(TaoBaseHandler):
         invoke_result_data.data = {"condition": "", "params": [], "order_by": "create_date desc"}
         return invoke_result_data
 
+
 class UpdatePrizeOrderSellerRemarkHandler(TaoBaseHandler):
     """
     :description: 更新奖品订单卖家备注
@@ -287,14 +288,15 @@ class PrizeOrderExportHandler(TaoBaseHandler):
 
         order_base_model = OrderBaseModel(context=self)
         prize_order_list_dict = order_base_model.get_prize_order_list(app_id, act_id, tb_user_id, user_open_id, nick_name, order_no, real_name, telephone, address, order_status, create_date_start, create_date_end, page_size, page_index, order_by, is_search_roster=True, is_cache=False).data
-        result_data = self.business_process_executed(prize_order_list_dict)
+        result_data = self.business_process_executed(prize_order_list_dict, self.request_params)
         resource_path = OSS2Helper.export_excel(result_data)
         return self.response_json_success(resource_path)
 
-    def business_process_executed(self, prize_order_list_dict):
+    def business_process_executed(self, prize_order_list_dict,request_params):
         """
         :description: 执行后事件
         :param prize_order_list_dict:订单列表
+        :param request_params: 请求参数字典
         :return:
         :last_editors: HuangJianYi
         """
@@ -379,14 +381,15 @@ class PrizeRosterExportHandler(TaoBaseHandler):
             prize_status = 1
         order_base_model = OrderBaseModel(context=self)
         prize_roster_list_dict = order_base_model.get_prize_roster_list(app_id, act_id, module_id, user_id, user_open_id, user_nick, order_no, goods_type, prize_type, logistics_status, prize_status, pay_status, page_size, page_index, create_date_start, create_date_end).data
-        result_data = self.business_process_executed(prize_roster_list_dict)
+        result_data = self.business_process_executed(prize_roster_list_dict,self.request_params)
         resource_path = OSS2Helper.export_excel(result_data)
         return self.response_json_success(resource_path)
 
-    def business_process_executed(self, prize_roster_list_dict):
+    def business_process_executed(self, prize_roster_list_dict, request_params):
         """
         :description: 执行后事件
         :param prize_roster_list_dict:中奖记录列表
+        :param request_params: 请求参数字典
         :return:
         :last_editors: HuangJianYi
         """
@@ -394,12 +397,14 @@ class PrizeRosterExportHandler(TaoBaseHandler):
         for prize_roster_dict in prize_roster_list_dict:
             data_row = {}
             data_row["行为编号"] = prize_roster_dict["id"]
+            data_row["小程序订单号"] = prize_roster_dict["order_no"]
             data_row["淘宝子订单号"] = prize_roster_dict["sub_pay_order_no"]
             data_row["淘宝名"] = prize_roster_dict["user_nick"]
             data_row["模块名称"] = prize_roster_dict["module_name"]
             data_row["奖品名称"] = prize_roster_dict["prize_name"]
             data_row["奖品价值"] = str(prize_roster_dict["prize_price"])
             data_row["奖品规格"] = prize_roster_dict["sku_name"]
+            data_row["商家编码"] = prize_roster_dict["goods_code"]
             data_row["获得时间"] = prize_roster_dict["create_date"]
             if prize_roster_dict["order_no"] == "":
                 data_row["状态"] = "未下单"
