@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-11-16 13:44:20
-@LastEditTime: 2021-09-09 14:49:47
+@LastEditTime: 2021-09-10 10:17:35
 @LastEditors: HuangJianYi
 :description: 
 """
@@ -33,7 +33,9 @@ class StatReportListHandler(TaoBaseHandler):
         end_date = self.get_param("end_date")
 
         stat_base_model = StatBaseModel(context=self)
-        return self.response_json_success(self.business_process_executed(stat_base_model.get_stat_report_list(app_id, act_id, module_id, start_date, end_date), self.request_params))
+        stat_report_list = stat_base_model.get_stat_report_list(app_id, act_id, module_id, start_date, end_date)
+        stat_report_list = self.business_process_executed(stat_report_list, self.request_params)
+        return self.response_json_success(stat_report_list)
 
     def business_process_executed(self, stat_report_list, request_params):
         """
@@ -69,7 +71,9 @@ class TrendReportListHandler(TaoBaseHandler):
         end_date = self.get_param("end_date")
 
         stat_base_model = StatBaseModel(context=self)
-        return self.response_json_success(self.business_process_executed(stat_base_model.get_trend_report_list(app_id, act_id, module_id, start_date, end_date), self.request_params))
+        trend_report_list = stat_base_model.get_trend_report_list(app_id, act_id, module_id, start_date, end_date)
+        trend_report_list = self.business_process_executed(trend_report_list, self.request_params)
+        return self.response_json_success(trend_report_list)
 
     def business_process_executed(self, trend_report_list, request_params):
         """
