@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-27 10:52:51
-@LastEditTime: 2021-09-09 11:01:39
+@LastEditTime: 2021-09-09 17:38:01
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -124,7 +124,7 @@ class UpdateUserStatusByBlackHandler(TaoBaseHandler):
 
 class AuditUserBlackHandler(TaoBaseHandler):
     """
-    docstring 审核黑名单状态
+    :description 审核黑名单状态
     """
     @filter_check_params("black_id,audit_status")
     def get_async(self):
@@ -149,7 +149,7 @@ class AuditUserBlackHandler(TaoBaseHandler):
 
 class UpdateAuditRemarkHandler(TaoBaseHandler):
     """
-    docstring 修改审核备注
+    :description 修改审核备注
     """
     @filter_check_params("black_id,audit_status")
     def get_async(self):
@@ -172,7 +172,7 @@ class UpdateAuditRemarkHandler(TaoBaseHandler):
 
 class UserBlackListHandler(TaoBaseHandler):
     """
-    获取黑名单管理列表
+    :description: 获取黑名单管理列表
     """
     @filter_check_params("act_id")
     def get_async(self):
@@ -357,22 +357,13 @@ class UserInfoListHandler(TaoBaseHandler):
         end_date = self.get_param("end_date")
         user_base_model = UserBaseModel(context=self)
         page_info = user_base_model.get_user_list(app_id, act_id, page_size, page_index, user_state, user_id, start_date, end_date, user_nick, open_id)
-        return self.reponse_json_success(self.business_process_executed(page_info, app_id, act_id, page_size, page_index, user_state, user_id, start_date, end_date, user_nick, open_id))
+        return self.reponse_json_success(self.business_process_executed(page_info, self.request_params))
 
-    def business_process_executed(self, page_info, app_id, act_id, page_size, page_index, user_state, user_id, start_date, end_date, user_nick, open_id):
+    def business_process_executed(self, page_info, request_params):
         """
         :description: 执行后事件
         :param page_info:用户信息分页实体模型
-        :param app_id：应用标识
-        :param act_id：活动标识
-        :param user_id：用户标识
-        :param open_id：_open_id
-        :param user_nick：用户昵称
-        :param user_state：_用户状态0正常1黑名单
-        :param page_index：页索引
-        :param page_size：页大小
-        :param start_date：创建时间开始
-        :param end_date：创建时间结束
+        :param request_params: 请求参数字典
         :return:
         :last_editors: HuangJianYi
         """
