@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-15 11:30:45
-@LastEditTime: 2021-08-25 09:32:03
+@LastEditTime: 2021-09-09 19:06:30
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -95,6 +95,8 @@ class OSS2Helper:
         resource_path = ""
         if import_data:
             try:
+                if not os.path.exists("temp"):
+                    os.makedirs("temp")
                 path = "temp/" + UUIDHelper.get_uuid() + ".xlsx"
                 ExcelHelper.export(import_data, path)
                 resource_path = self.upload("", path, config.get_value("oss_folder"), False)
