@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-01-14 10:44:07
-@LastEditTime: 2021-09-08 19:32:23
+@LastEditTime: 2021-09-10 11:12:56
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -61,6 +61,40 @@ class TikTokHelper:
             self.logger_error.error(str(ex) + "【code2_session】" + str(resp.text))
             return {}
 
+    @classmethod
+    def get_access_token(self, grant_type="client_credential"):
+        """
+        :description:access_token 是小程序的全局唯一调用凭据，开发者调用小程序支付时需要使用 access_token。access_token 的有效期为 2 个小时，需要定时刷新 access_token，重复获取会导致之前一次获取的 access_token 的有效期缩短为 5 分钟。
+        :param grant_type: 获取access_token 时值为 client_credential
+        :return: 
+        :last_editors: HuangJianYi
+        """
+        redis_key = "tiktok_access_token"
+        redis_init = SevenHelper.redis_init()
+        access_token_dict = redis_init.get(redis_key)
+        if access_token_dict:
+            access_token_dict = SevenHelper.json_loads(access_token_dict)
+            return access_token_dict
+        app_id = config.get_value("app_id")
+        app_secret = config.get_value("app_secret")
+        param = {
+            'appid': app_id,
+            'secret': app_secret,
+            'grant_type': grant_type,
+        }
+
+        # 通过code获取access_token
+        requset_url = 'https://developer.toutiao.com/api/apps/token'
+        resp = None
+        try:
+            resp = requests.get(requset_url, params=param)
+            redis_init.set(redis_key, resp, ex=60 * 60)
+            res_result = json.loads(resp.text)
+            return res_result
+        except Exception as ex:
+            self.logger_error.error(str(ex) + "【get_access_token】" + str(resp.text))
+            return {}
+
     @classmethod
     def decrypt_data_by_code(self, open_id, code, encrypted_Data, iv):
         """
@@ -369,7 +403,6 @@ class TikTokPayRequest(object):
             invoke_result_data.error_message = "退款出现异常，请重试"
             return invoke_result_data
 
-
     def query_refund(self, out_refund_no="", thirdparty_id=""):
         """
         :desciption:退款查询
