@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-19 09:23:14
-@LastEditTime: 2021-09-08 19:33:19
+@LastEditTime: 2021-09-10 13:32:20
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -55,6 +55,8 @@ class WeChatHelper:
         try:
             resp = requests.get(requset_url, params=param)
             res_result = SevenHelper.json_loads(resp.text)
+            if res_result.errcode != 0:
+                return None
             open_id = res_result['openid']
             session_key = res_result['session_key']
             redis_init.set(redis_key, SevenHelper.json_dumps(res_result), ex=60 * 60)
