@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-04-16 14:38:22
-@LastEditTime: 2021-09-09 11:25:27
+@LastEditTime: 2021-09-10 11:35:33
 @LastEditors: HuangJianYi
 :Description: 基础路由   业务方可以直接使用语句 handlers.extend(seven_cloudapp_frame.route.seven_cloudapp_frame_route()) 引入
 """
@@ -52,11 +52,12 @@ def seven_cloudapp_frame_route():
         (r"/client/invite_new_user", task.InviteNewUserHandler),  #邀请新用户任务
         (r"/client/invite_join_member", task.InviteJoinMemberHandler),  #邀请加入会员任务
         (r"/client/browse_site", task.BrowseSiteHandler),  #处理浏览网址相关任务 如：浏览店铺、浏览直播间、浏览会场/专题
-        (r"/client/share_report", task.ShareReportHandler),  #分享统计上报
         (r"/client/collect_goods", task.CollectGoodsHandler),  #收藏商品任务
         (r"/client/browse_goods", task.BrowseGoodsHandler),  #浏览商品任务
         (r"/client/favor_store", task.FavorStoreHandler),  #关注店铺任务
         (r"/client/join_member", task.JoinMemberHandler),  #加入会员任务
+        (r"/client/share_report", stat.ShareReportHandler),  #分享统计上报
+        (r"/client/invite_report", stat.InviteReportHandler),  #邀请进入统计上报
 
         #淘宝千牛端
         (r"/server/saas_custom", base_s.SaasCustomHandler),  #saas定制化信息获取
